@@ -347,5 +347,8 @@ module.exports = {
   OSIS: require('./osis'),
   MediaPackageV2: require('./mediapackagev2'),
   PaymentCryptography: require('./paymentcryptography'),
-  PaymentCryptographyData: require('./paymentcryptographydata')
+  PaymentCryptographyData: require('./paymentcryptographydata'),
+  CodeGuruSecurity: require('./codegurusecurity'),
+  VerifiedPermissions: require('./verifiedpermissions'),
+  AppFabric: require('./appfabric')
 };
\ No newline at end of file
